import * as React from "react";
import { styled } from "@mui/material/styles";
import Table from "@mui/material/Table";
import TableBody from "@mui/material/TableBody";
import TableCell, { tableCellClasses } from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import TableHead from "@mui/material/TableHead";
import TableRow from "@mui/material/TableRow";
import Paper, { paperClasses } from "@mui/material/Paper";
import { Box, Button, IconButton, Menu } from "@mui/material";
import MoreVertRoundedIcon from "@mui/icons-material/MoreVertRounded";
import { useDispatch } from "react-redux"; // Correct the import for dispatch
import { AppDispatch } from "../../redux/store/store";
const StyledTableCell = styled(TableCell)(({ theme }) => ({
	[`&.${tableCellClasses.head}`]: {
		backgroundColor: " #1565c0",
		color: theme.palette.common.white,
	},
	[`&.${tableCellClasses.body}`]: {
		fontSize: 14,
	},
}));

const StyledTableRow = styled(TableRow)(({ theme }) => ({
	"&:nth-of-type(odd)": {
		backgroundColor: theme.palette.action.hover,
	},
	"&:last-child td, &:last-child th": {
		border: 0,
	},
}));

export interface Column {
	id: string;
	label: string;
	align?: "left" | "center" | "right";
}

interface Row {
	[key: string]: any;
	status: number;
	statusValue: any;
}

interface CustomTableProps {
	columns: Column[];
	rows: Row[];
	setDeleteModal: Function;
	// setRowData: Function;
	// setModalOpen: Function;
	viewModal: boolean;
	setViewModal: Function;
	deleteModal: boolean;
	setRowData: React.Dispatch<React.SetStateAction<any>>; // Adjust this type if needed
	setModalOpen: React.Dispatch<React.SetStateAction<boolean>>;
	handleStatusToggle: (id: string, currentStatus: number) => void;
}

const CustomTable: React.FC<CustomTableProps> = ({
	columns,
	rows,
	setDeleteModal,
	deleteModal,
	viewModal,
	setRowData,
	setViewModal,
	setModalOpen,
	handleStatusToggle,
}) => {
	const [anchorEl, setAnchorEl] = React.useState<null | HTMLElement>(null);
	const [selectedRow, setSelectedRow] = React.useState<Row | null>(null);

	const open = Boolean(anchorEl);
	///const dispatch = useDispatch(); // Initialize dispatch

	// Handle menu actions
	const handleClick = (event: React.MouseEvent<HTMLElement>, row: Row) => {
		setAnchorEl(event.currentTarget);
		setSelectedRow(row);
	};

	const handleClose = () => {
		setAnchorEl(null);
	};
	const dispatch = useDispatch<AppDispatch>();
	// Handle status toggle logic
	// const handleStatusToggle = (id: string, status: number) => {
	// 	dispatch(toggleStatus({ id, status })); // Dispatch the action to update status
	// };

	return (
		<Box sx={{ overflowX: "auto", width: "100%" }}>
			<TableContainer component={Paper}>
				<Table sx={{ minWidth: 700 }} aria-label="customized table">
					<TableHead>
						<TableRow>
							{columns.map((column) => (
								<StyledTableCell
									key={column.id}
									align={column.align}
								>
									{column.label}
								</StyledTableCell>
							))}
						</TableRow>
					</TableHead>
					<TableBody>
						{rows.map((row, rowIndex) => (
							<StyledTableRow key={rowIndex}>
								{columns.map((column) => (
									<StyledTableCell
										key={column.id}
										align={column.align}
									>
										{column.id !== "action" ? (
											row[column.id]
										) : (
											<IconButton
												onClick={(e) =>
													handleClick(e, row)
												}
											>
												<MoreVertRoundedIcon />
											</IconButton>
										)}
									</StyledTableCell>
								))}
							</StyledTableRow>
						))}
					</TableBody>
				</Table>
			</TableContainer>

			{/* Menu Actions */}
			{open && selectedRow && (
				<Menu
					anchorEl={anchorEl}
					open={open}
					onClose={handleClose}
					onClick={handleClose}
				>
					<Button
						variant="text"
						onClick={(e) => {
							e.stopPropagation();
							setViewModal(true);
						}}
					>
						View
					</Button>
					<Button variant="text" onClick={() => setModalOpen(true)}>
						Edit
					</Button>
					{/* This button now toggles the status based on the current status */}
					<Button
						variant="text"
						onClick={(e) => {
							e.stopPropagation();
							const newStatus = selectedRow?.status === 0 ? 0 : 1;
							handleStatusToggle(selectedRow?.id, newStatus);
						}}
					>
						{selectedRow?.status === 1 ? "Deactivate" : "Activate"}
					</Button>

					<Button
						variant="text"
						onClick={(e) => {
							e.stopPropagation();
							setDeleteModal(true);
						}}
					>
						Delete
					</Button>
				</Menu>
			)}
		</Box>
	);
};

export default CustomTable;
